@@ -12,7 +12,8 @@ from trytond.pyson import Eval, If, Bool
 from trytond.wizard import Wizard, StateView, StateTransition, \
     Button, StateAction
 from trytond.transaction import Transaction
-from trytond.model import ModelSQL, ModelView, Workflow, fields
+from trytond.model import (ModelSQL, ModelView, Workflow, fields,
+    DeactivableMixin)
 from trytond.exceptions import UserError
 from trytond.i18n import gettext
 
@@ -23,7 +24,7 @@ STATES = {
 DEPENDS = ['active']
 
 
-class PaymentGateway(ModelSQL, ModelView):
+class PaymentGateway(DeactivableMixin, ModelSQL, ModelView):
     """
     Payment Gateway
 
@@ -31,9 +32,8 @@ class PaymentGateway(ModelSQL, ModelView):
     """
     __name__ = 'payment_gateway.gateway'
 
-    active = fields.Boolean('Active', select=True)
     name = fields.Char(
-        'Name', required=True, select=True, states=STATES, depends=DEPENDS
+        'Name', required=True, states=STATES, depends=DEPENDS
     )
     journal = fields.Many2One(
         'account.journal', 'Journal', required=True,
@@ -81,10 +81,6 @@ class PaymentGateway(ModelSQL, ModelView):
             gateway.configured = configured
             gateway.save()
 
-    @staticmethod
-    def default_active():
-        return True
-
     @staticmethod
     def default_provider():
         return 'self'
@@ -117,12 +113,12 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
         [
             ('charge', 'Charge'),
             ('refund', 'Refund'),
-        ], 'Type', required=True, select=True,
+        ], 'Type', required=True,
         states=READONLY_IF_NOT_DRAFT,
         depends=['state']
     )
     origin = fields.Reference(
-        'Origin', selection='get_origin', select=True,
+        'Origin', selection='get_origin',
         states=READONLY_IF_NOT_DRAFT,
         depends=['state']
     )
@@ -216,7 +212,7 @@ class PaymentTransaction(Workflow, ModelSQL, ModelView):
             ('type.receivable', '=', True)
             ],
         states=READONLY_IF_NOT_DRAFT, depends=['company', 'state'],
-        required=True, select=True)
+        required=True)
     last_four_digits = fields.Char('Last Four Digits')
     charge_id = fields.Char("Charge ID", readonly=True)
     dispute_reason = fields.Char("Dispute Reason", readonly=True,
@@ -896,7 +892,7 @@ class BaseCreditCardViewMixin(object):
             # TODO: Match track 2
 
 
-class PaymentProfile(ModelSQL, ModelView):
+class PaymentProfile(DeactivableMixin, ModelSQL, ModelView):
     """
     Secure Payment Profile
 
@@ -943,7 +939,6 @@ class PaymentProfile(ModelSQL, ModelView):
     expiry_year = fields.Char(
         'Expiry Year', required=True, size=4, readonly=True
     )
-    active = fields.Boolean('Active', select=True)
 
     @staticmethod
     def default_sequence():
@@ -959,10 +954,6 @@ class PaymentProfile(ModelSQL, ModelView):
             return ' '.join([self.gateway.name, 'xxxx', self.last_4_digits])
         return 'Incomplete Card'
 
-    @staticmethod
-    def default_active():
-        return True
-
 
 class AddPaymentProfileView(BaseCreditCardViewMixin, ModelView):
     """
